<?php
/**
 * Traitement abonnement à des listes de diffusion à la saisie d'un formulaire
 *
 * @note
 * On s'aligne sur le formulaire `newsletter_subscribe` :
 * - on ne permet de s'inscrire qu'aux listes ouvertes, même si la saisie permet d'afficher les fermées.
 * - mode non graceful
 *
 * @see formidable_mailsubscribers_formulaire_charger()
 *
 * @plugin     Formidable : abonnement à des listes de diffusion
 * @copyright  2017
 * @author     tcharlss
 * @licence    GNU/GPL
 * @package    SPIP\FormidableMailsubscribers\traiter\mailsubscribe
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Traitements
 *
 * @uses newsletter_subscribe_dist()
 * @see formulaires_newsletter_subscribe_traiter_dist()
 *
 * @param array $args
 *     Tableau associatif :
 *     - formulaire
 *     - options : noms des champs, etc.
 * @param array $retours
 *     Tableau associatif :
 *     - editable (bool)
 *     - formidable_afficher_apres (string) : `formulaire` | …
 *     - id_formulaire (int)
 *     - traitements (array) : liste des traitements effectués
 *     - message_ok (string)
 * @return array
 */
function traiter_mailsubscribe_dist($args, $retours) {

	$formulaire  = $args['formulaire'];
	$options     = $args['options'];
	$saisies     = unserialize($formulaire['saisies']);
	$traitements = unserialize($formulaire['traitements']);

	// Noms des champs configurés
	$champ_email  = (isset($options['champ_email_mailsubscribe']) ? $options['champ_email_mailsubscribe'] : null);
	$champ_nom    = (isset($options['champ_nom_mailsubscribe']) ? $options['champ_nom_mailsubscribe'] : null);
	$champ_listes = (isset($options['champ_listes_mailsubscribe']) ? $options['champ_listes_mailsubscribe'] : null);

	// Il faut un email et des listes cochées pour procéder
	if (
		$email = _request($champ_email)
		and $listes = _request($champ_listes)
	) {

		include_spip('inc/config');
		include_spip('inc/nospam');
		include_spip('inc/filtres');
		include_spip('base/abstract_sql');
		include_spip('inc/mailsubscribers');

		$options_subscribe = array();
		// S'assurer que les listes choisies sont ouvertes
		$listes_dispo = mailsubscribers_listes(array('status' => 'open'));
		$listes = array_intersect($listes, array_keys($listes_dispo));
		$options_subscribe['listes'] = $listes;
		// Langue par défaut lors de l'inscription : la langue courante dans la page
		$options_subscribe['lang'] = $GLOBALS['spip_lang'];
		// On permet aux désinscrits de se réinscrire
		$options_subscribe['graceful'] = false;
		// Le nom avec un fallback
		if ($nom = (_request($champ_nom) ? _request($champ_nom) : sql_getfetsel('nom', 'spip_auteurs', 'email = ' . sql_quote($email)))) {
			$options_subscribe['nom'] = $nom;
		}
		// Notification
		if (!empty($options['notify'])) {
			$options_subscribe['notify'] = true;
		}

		// Message de retour en fonction du double opt-in
		if (lire_config('mailsubscribers/double_optin', 0)) {
			$message_ok = _T('newsletter:subscribe_message_ok_confirm', array('email' => "<b>$email</b>"));
		} else {
			$message_ok = _T('newsletter:subscribe_message_ok', array('email' => "<b>$email</b>"));
		}

		// Si nospam, ne déclencher l'action qu'après le POST
		if (function_exists('nospam_confirm_action_html')) {
			$html_confirm = nospam_confirm_action_html('subscribe', "Subscribe $email " . json_encode($options_subscribe), array($email, $options_subscribe), 'newsletter/');
			$message_ok .= $html_confirm;
		// Soit go go go direct
		} else {
			$newsletter_subscribe = charger_fonction('subscribe', 'newsletter');
			if (!$ok = $newsletter_subscribe($email, $options_subscribe)) {
				$message_ok = '';
				$message_erreur = _T('mailsubscriber:erreur_technique_subscribe');
			}
		}

		// Indiquer que ces messages de retour concernent ce traitement
		$intro_message = singulier_ou_pluriel(count($listes), 'formidable_mailsubscribers:info_inscription_liste', 'formidable_mailsubscribers:info_inscription_listes');
		if ($message_ok) {
			$sep = ($retours['message_ok'] ? '<br>' : '');
			$retours['message_ok'] .= $sep . $intro_message . $message_ok;
		}
		if ($message_erreur) {
			$sep = ($retours['message_erreur'] ? '<br>' : '');
			$retours['message_erreur'] .= $sep . $intro_message . $message_erreur;
		}
	}

	// noter qu'on a déjà fait le boulot, pour ne pas risquer double appel
	$retours['traitements']['newsletters'] = true;

	return $retours;
}
